==> adms-2.2.4.tar.gz: adms-2.2.4/admsObject/objectNilled.h <==

/* ------- code automatically created by ../scripts/adms_build_object.pl -------------- */

#ifndef objectnilled_h
#define objectnilled_h
#include <admsObject/admsH.h>
#include <admsObject/objectMath.h>
struct s_nilled {
  t_math _math;
  p_module _module;
  int _module_isdefault : 1;
  char* _name;
  int _name_isdefault : 1;
};
#include <admsObject/objectModule.h>

#undef win32_interface
#if defined(WIN32)
#  if defined(_inside_admsObject)
#    define win32_interface __declspec(dllexport)
#  else
#    define win32_interface __declspec(dllimport)
#  endif
#else
#  define win32_interface extern
#endif

win32_interface char*adms_nilled_getuid (p_nilled mynilled);
win32_interface gboolean adms_nilled_cmp (p_nilled mynilled,p_nilled refnilled);
win32_interface p_nilled adms_nilled_new_1 (p_module mymodule);
#define adms_nilled_free_debug(item)\
  adms_adms(item)->_freed=adms_adms_enumeration_freed_yes;
#define adms_nilled_free(item)\
{\
  free(item->_name);\
  free(item);\
}
win32_interface p_adms adms_nilled_new_impl (p_adms arguments[]);
win32_interface p_nilled adms_nilled_impl (void* member);
#define adms_nilled(member) ((p_nilled) (member))
#define adms_nilled_new adms_nilled_new_1
#define adms_nilled_isdefault_module(nilled) (adms_nilled(nilled)->_module_isdefault)
#define adms_nilled_valueof_module(nilled) (adms_nilled(nilled)->_module)
#define adms_nilled_isdefault_name(nilled) (adms_nilled(nilled)->_name_isdefault)
#define adms_nilled_valueof_name(nilled) (adms_nilled(nilled)->_name)
#define adms_nilled_valueof_math(nilled) ((p_math)nilled)
#define adms_nilled_valueof_adms(nilled) ((p_adms)nilled)
#define adms_nilled_valueto_module(a,b) ((p_nilled)a)->_module=(b)
win32_interface void adms_nilled_valueto_module_impl (p_nilled mynilled,p_module _module);
#define adms_nilled_valueto_name(a,b) ((p_nilled)a)->_name=(b)
win32_interface void adms_nilled_valueto_name_impl (p_nilled mynilled,char* _name);
#endif /* objectnilled_h */

==> adms-2.2.5.tar.gz: adms-2.2.5/admsObject/objectNilled.h <==

/* ------- code automatically created by ../scripts/adms_build_object.pl -------------- */

#ifndef objectnilled_h
#define objectnilled_h
#include <admsObject/admsH.h>
#include <admsObject/objectMath.h>
struct s_nilled {
  t_math _math;
  p_module _module;
  int _module_isdefault : 1;
  p_quark _name;
  int _name_isdefault : 1;
};
#include <admsObject/objectModule.h>
#include <admsObject/objectQuark.h>

#undef win32_interface
#if defined(WIN32)
#  if defined(_inside_admsObject)
#    define win32_interface __declspec(dllexport)
#  else
#    define win32_interface __declspec(dllimport)
#  endif
#else
#  define win32_interface extern
#endif

win32_interface char*adms_nilled_uid (p_nilled mynilled);
win32_interface int adms_nilled_cmp (p_nilled mynilled,p_nilled refnilled);
win32_interface p_nilled adms_nilled_new(p_module mymodule);
win32_interface p_adms adms_nilled_new_impl (p_adms arguments[]);
#define adms_nilled(member) ((p_nilled) (member))
#define adms_nilled_isdefault_module(nilled) (adms_nilled(nilled)->_module_isdefault)
#define adms_nilled_valueof_module(nilled) (adms_nilled(nilled)->_module)
#define adms_nilled_isdefault_name(nilled) (adms_nilled(nilled)->_name_isdefault)
#define adms_nilled_valueof_name(nilled) (adms_nilled(nilled)->_name)
#define adms_nilled_valueof_math(nilled) ((p_math)nilled)
#define adms_nilled_valueof_adms(nilled) ((p_adms)nilled)
win32_interface inline void adms_nilled_valueto_module (p_nilled mynilled,p_module _module);
win32_interface inline void adms_nilled_valueto_name (p_nilled mynilled,p_quark _name);
win32_interface inline void adms_nilled_free(p_nilled mynilled);
#endif /* objectnilled_h */
